'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateInterface = exports.filenameToTypingsFilename = undefined;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var filenameToInterfaceName = function filenameToInterfaceName(filename) {
  return _path2.default.basename(filename).replace(/^(\w)/, function (_, c) {
    return 'I' + c.toUpperCase();
  }).replace(/\W+(\w)/g, function (_, c) {
    return c.toUpperCase();
  });
};

var cssModuleToTypescriptInterfaceProperties = function cssModuleToTypescriptInterfaceProperties(cssModuleObject) {
  var indent = arguments.length <= 1 || arguments[1] === undefined ? '  ' : arguments[1];

  return Object.keys(cssModuleObject).map(function (key) {
    return indent + '\'' + key + '\': string;';
  }).join('\n');
};

var filenameToTypingsFilename = exports.filenameToTypingsFilename = function filenameToTypingsFilename(filename) {
  var dirName = _path2.default.dirname(filename);
  var baseName = _path2.default.basename(filename);
  return _path2.default.join(dirName, baseName + '.d.ts');
};

var generateInterface = exports.generateInterface = function generateInterface(cssModuleObject, filename, indent) {
  var interfaceName = filenameToInterfaceName(filename);
  var interfaceProperties = cssModuleToTypescriptInterfaceProperties(cssModuleObject, indent);
  return 'export interface ' + interfaceName + ' {\n' + interfaceProperties + '\n}\ndeclare const styles: ' + interfaceName + ';\n\nexport default styles;\n';
};